# sec-vault
## Overview
`sec-vault` is a SWISS army knife toolkit for in-house password management which provides interfaces for experts 
who wish to have a more granular control on choosing external
- cipher suites and primitives
- cryptographic libraries 
- toolkits/utilities of their choice

> **Note:** Use this password management solution at your own risk. I do not claim any responsibility towards the use of this software.
> The strength of the files in the vault is determined by the cipher suite incorporated along with the cryptographic primitives used to configure
> the same. Unless you are technically adept, please avoid using this program at all costs.